@@ -1,4 +1,5 @@
 from os import path, walk
+import json
 
 BASE = path.dirname(__file__)
 
@@ -14,11 +15,11 @@ app.secret_key = \"YOUR SECRET KEY\"\n
 # Build server.py based on app name
 def server_py(app_name="flask_app"):
     return f"""
-    from {app_name}.controllers import #TODO controllers go here\n
-    from {app_name} import app\n
-    if __name__==\"__main__\":\n
-    \tapp.run(debug=True)
-    """
+from {app_name}.controllers import #TODO controllers go here\n
+from {app_name} import app\n
+if __name__==\"__main__\":\n
+\tapp.run(debug=True)
+"""
 
 # File builder from .txt
 def _file_from_text(file_name):
@@ -30,8 +31,16 @@ TEST_TEXT = _file_from_text("test.txt")
 
 HELP = _file_from_text("help.txt")
 
+CD_MVC = json.loads(_file_from_text("patterns/CD_MVC.json"))
+
 MYSQLCONNECTION = _file_from_text("database_configs/mysqlconnection.txt")
 
+
 MODELS = []
 for (dirpath, dirname, fnames ) in walk(path.join(BASE, "models")):
     MODELS.extend(fnames)
+
+VAULT = {
+    "app_module_file": APP_MODULE_FILE,
+    "mysql": MYSQLCONNECTION,
+}
